class Wrapper:
    def __init__(self, fn, *args, **kwargs):
        self._fn = fn
        self._args = args
        self._kwargs = kwargs

    def __call__(self, fn):
        def wrapper(*args, **kwargs):
            return self._fn(fn(*args, **kwargs), *self._args, **self._kwargs)
        return wrapper



from wraptitude import Wrapper


def test_args():
    @Wrapper(dict, a=3, b=4)
    def f(**kwargs):
        return kwargs

    assert f(c=1, d=2) == {
        'a': 3,
        'b': 4,
        'c': 1,
        'd': 2
    }


def test_dict():
    @Wrapper(dict)
    def f(x):
        for i in range(x):
            yield str(i), float(i)

    assert f(12) == {str(x): float(x) for x in range(12)}


def test_identity():
    @Wrapper(lambda x: x)
    def f(x):
        return x + 1

    assert (f(-2), f(-1), f(0), f(1)) == (-1, 0, 1, 2)


def test_list():
    @Wrapper(list)
    def f(x):
        for i in range(x):
            yield i ** 2

    assert f(3) == [x ** 2 for x in range(3)]



from distutils.core import setup

with open('README.rst', 'r') as readme:
    long_description = readme.read()

setup(
    name='wraptitude',
    version='0.0.0',
    description='Wrap the results of your Python functions',
    long_description=long_description,
    author='Brett Beatty',
    author_email='brettbeatty@gmail.com',
    url='https://github.com/brettbeatty/wraptitude',
    packages=['wraptitude'],
    package_data={'': ['LICENSE', 'README.rst']},
    include_package_data=True,
    keywords=['wrapper', 'decorator']
)
